@@ -14,38 +14,25 @@
 #
 #  @author Marcello Stanisci
 
-from django.test import TestCase, Client
-from django.core.urlresolvers import reverse
-from django.conf import settings
-from django.contrib.auth.models import User
-from .models import BankAccount, BankTransaction
-from . import urls
-from . import amounts
-from .views import wire_transfer
-import json
-
 import logging
+from django.test import TestCase
+from django.conf import settings
+from .amount import Amount, BadFormatAmount
 
-logger = logging.getLogger(__name__)
+LOGGER = logging.getLogger()
+LOGGER.setLevel(logging.WARNING)
 
+class BadMaxDebitOptionTestCase(TestCase):
+    def test_badmaxdebitoption(self):
+        with self.assertRaises(BadFormatAmount):
+            Amount.parse(settings.TALER_MAX_DEBT)
+            Amount.parse(settings.TALER_MAX_DEBT_BANK)
+
+# Note, the two following classes are used to check a faulty
+# _config_ file, so they are not supposed to have any logic.
 class BadDatabaseStringTestCase(TestCase):
     def test_baddbstring(self):
         pass
 
-class BadMaxDebtOptionTestCase(TestCase):
-    def test_badmaxdebtoption(self):
-        try:
-            amounts.parse_amount(settings.TALER_MAX_DEBT)
-        except amounts.BadFormatAmount:
-            self.assertTrue(True)
-            return
-        try:
-            amounts.parse_amount(settings.TALER_MAX_DEBT_BANK)
-        except amounts.BadFormatAmount:
-            self.assertTrue(True)
-            return
-        # Force to have at least one bad amount in config
-        self.assertTrue(False)
-
 class NoCurrencyOptionTestCase(TestCase):
     pass
