@@ -14,12 +14,11 @@ Including another URLconf
     1. Import the include() function: from django.conf.urls import url, include
     2. Add a URL to urlpatterns:  url(r'^blog/', include('blog.urls'))
 """
-from django.conf.urls import include, url
 from django.contrib.staticfiles.urls import staticfiles_urlpatterns
+from django.conf.urls import url
 from django.contrib import admin
 
 urlpatterns = [
-    url(r'^', include('talerbank.app.urls')),
     url(r'^djangoadmin/', admin.site.urls),
 ]
 
